#!/usr/bin/env python
# -*- coding: utf-8 -*-

from twisted.enterprise import adbapi
from twisted.internet import reactor
from twisted.web.server import NOT_DONE_YET, Site
from twisted.web.resource import Resource


class SignInPage(Resource):
    
    def _getErrorPage(self, message):
        with open("error.html") as f:
            return f.read().format(message)
    
    def _userCreated(self, ret, request):
        request.write("Su usuario ha sido creado.")
        request.finish()
    
    def render_GET(self, request):
        with open("signin.html") as f:
            return f.read()
    
    def render_POST(self, request):
        username = request.args["username"][0]
        email = request.args["email"][0]
        password = request.args["password"][0]
        password2 = request.args["password2"][0]
        
        if not username or not email or not password or not password2:
            return self._getErrorPage(
                "Por favor complete todos los campos.")
        elif password != password2:
            return self._getErrorPage("Las constraseñas no coinciden.")
        
        dbpool = adbapi.ConnectionPool("sqlite3", "users.db")
        d = dbpool.runQuery("INSERT INTO users VALUES (?, ?, ?)",
                            (username, email, password))
        d.addCallback(self._userCreated, request)
        
        return NOT_DONE_YET


root = Resource()
root.putChild("signin", SignInPage())
factory = Site(root)
reactor.listenTCP(8080, factory)
reactor.run()
