#!/usr/bin/env python
# -*- coding: utf-8 -*-

from twisted.enterprise import adbapi
from twisted.internet import reactor
from twisted.web.server import NOT_DONE_YET, Site
from twisted.web.resource import Resource


class SignInPage(Resource):
    
    def _checkUserAvailability(self, not_available):
        if not_available:
            self._writeAndFinish("El usuario ya existe.")
        else:
            self._insertUser()
    
    def _createUser(self):
        d = self._dbpool.runQuery("SELECT name FROM users WHERE name=?",
                                  (self._username,))
        d.addCallback(self._checkUserAvailability)
    
    def _getErrorPage(self, message):
        with open("error.html") as f:
            return f.read().format(message)
    
    def _insertUser(self):
        d = self._dbpool.runQuery(
            "INSERT INTO users VALUES (?, ?, ?)",
            (self._username, self._email, self._password)
        )
        d.addCallback(self._userCreated)
    
    def _userCreated(self, ret):
        self._writeAndFinish("Su usuario ha sido creado.")
    
    def _writeAndFinish(self, message):
        self._request.write(message)
        self._request.finish()
    
    def render_GET(self, request):
        with open("signin.html") as f:
            return f.read()
    
    def render_POST(self, request):
        self._username = request.args["username"][0]
        self._email = request.args["email"][0]
        self._password = request.args["password"][0]
        password2 = request.args["password2"][0]
        
        if (not self._username or not self._email or
            not self._password or not password2):
            return self._getErrorPage(
                "Por favor complete todos los campos.")
        elif self._password != password2:
            return self._getErrorPage("Las constraseñas no coinciden.")
        
        self._request = request
        self._dbpool = adbapi.ConnectionPool("sqlite3", "users.db")
        self._createUser()
        
        return NOT_DONE_YET


root = Resource()
root.putChild("signin", SignInPage())
factory = Site(root)
reactor.listenTCP(8880, factory)
reactor.run()
